ConfigurationDescriptor

Struct ConfigurationDescriptor 

pub struct ConfigurationDescriptor {
    pub total_length: u16,
    pub num_interfaces: u8,
    pub value: u8,
    pub index: u8,
    pub attributes: ConfigurationAttributes,
    pub max_power: u8,
}
The configuration descriptor describes information about a specific device configuration.

The descriptor contains a bConfigurationValue field with a value that, when used as a parameter to the SetConfiguration() request, causes the device to assume the described configuration.

Fields

total_length: u16

Total length of data returned for this configuration.

Includes the combined length of all descriptors (configuration, interface, endpoint, and class- or vendor-specific) returned for this configuration.

num_interfaces: u8

Number of interfaces supported by this configuration

value: u8

Value to use as an argument to the SetConfiguration() request to select this configuration

index: u8

Index of string descriptor describing this configuration

attributes: ConfigurationAttributes

Configuration characteristics

max_power: u8

Maximum power consumption of the USB device from the bus in this specific configuration when the device is fully operational.

Expressed in 2 mA units (i.e., 50 = 100 mA).