DeviceAddress

Struct DeviceAddress 

pub struct DeviceAddress(/* private fields */);
An address that was assigned to a device by the host.

The address may or may not represent a device that is currently attached. Normally device addresses are not reused, except when the address counter overflows.

This type only represents assigned addresses, and thus cannot represent the special address 0. Address 0 is only used to assign an address to the device during enumeration, and should not be used by any drivers.